# PaymentMethodCardBinInfoCardClass

The type of the card.

## Enum

* `DEBIT` (value: `'Debit'`)

* `CREDIT` (value: `'Credit'`)

* `PREPAID` (value: `'Prepaid'`)

* `CHARGECARD` (value: `'ChargeCard'`)

* `DEFERREDDEBIT` (value: `'DeferredDebit'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


